@@ -1,7 +1,7 @@
 /* Open and close files for Bison.
 
    Copyright (C) 1984, 1986, 1989, 1992, 2000, 2001, 2002, 2003, 2004,
-   2005, 2006, 2007 Free Software Foundation, Inc.
+   2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -267,7 +267,9 @@ compute_file_name_parts (void)
       if (spec_file_prefix)
 	{
 	  /* If --file-prefix=foo was specified, ALL_BUT_TAB_EXT = `foo'.  */
-	  dir_prefix = xstrndup (grammar_file, base - grammar_file);
+	  dir_prefix =
+            xstrndup (spec_file_prefix,
+                      last_component (spec_file_prefix) - spec_file_prefix);
 	  all_but_tab_ext = xstrdup (spec_file_prefix);
 	}
       else if (yacc_flag)
@@ -351,6 +353,8 @@ compute_output_file_names (void)
 void
 output_file_name_check (char const *file_name)
 {
+  if (0 == strcmp (file_name, grammar_file))
+    fatal (_("refusing to overwrite the input file %s"), quote (file_name));
   {
     int i;
     for (i = 0; i < file_names_count; i++)
