@@ -1,30 +1,30 @@
 /* Parse command line arguments for Bison.
 
    Copyright (C) 1984, 1986, 1989, 1992, 2000, 2001, 2002, 2003, 2004,
-   2005, 2006 Free Software Foundation, Inc.
+   2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
-   Bison is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-   Bison is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Bison; see the file COPYING.  If not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 #include "system.h"
-#include "revision.h"
+#include "output.h"
 
 #include <argmatch.h>
+#include <c-strcase.h>
+#include <configmake.h>
 #include <error.h>
 
 /* Hack to get <getopt.h> to declare getopt with a prototype.  */
@@ -48,9 +48,9 @@
 bool debug_flag;
 bool defines_flag;
 bool graph_flag;
+bool xml_flag;
 bool locations_flag;
 bool no_lines_flag;
-bool no_parser_flag;
 bool token_table_flag;
 bool yacc_flag;	/* for -y */
 
@@ -58,24 +58,33 @@ bool error_verbose = false;
 
 bool nondeterministic_parser = false;
 bool glr_parser = false;
-bool pure_parser = false;
 
 int report_flag = report_none;
 int trace_flag = trace_none;
 int warnings_flag = warnings_none;
 
+static struct bison_language const valid_languages[] = {
+  { "c", "c-skel.m4", ".c", ".h", true },
+  { "c++", "c++-skel.m4", ".cc", ".hh", true },
+  { "java", "java-skel.m4", ".java", ".java", false },
+  { "", "", "", "", false }
+};
+
+int skeleton_prio = default_prio;
 const char *skeleton = NULL;
+int language_prio = default_prio;
+struct bison_language const *language = &valid_languages[0];
 const char *include = NULL;
 
-extern char *program_name;
+char *program_name;
 
 
 /** Decode an option's set of keys.
  *
  *  \param option   option being decoded.
- *  \paran keys     array of valid subarguments.
+ *  \param keys     array of valid subarguments.
  *  \param values   array of corresponding (int) values.
- *  \param flag     the flags to update
+ *  \param flags    the flags to update
  *  \param args     colon separated list of effective subarguments to decode.
  *                  If 0, then activate all the flags.
  *
@@ -89,15 +98,15 @@ flags_argmatch (const char *option,
   if (args)
     {
       args = strtok (args, ",");
-      do
+      while (args)
 	{
 	  int value = XARGMATCH (option, args, keys, values);
 	  if (value == 0)
 	    *flags = 0;
 	  else
 	    *flags |= value;
+	  args = strtok (NULL, ",");
 	}
-      while ((args = strtok (NULL, ",")));
     }
   else
     *flags = ~0;
@@ -106,7 +115,7 @@ flags_argmatch (const char *option,
 /** Decode a set of sub arguments.
  *
  *  \param FlagName  the flag familly to update.
- *  \param args      the effective sub arguments to decode.
+ *  \param Args      the effective sub arguments to decode.
  *
  *  \arg FlagName_args   the list of keys.
  *  \arg FlagName_types  the list of values.
@@ -201,19 +210,21 @@ static const char * const warnings_args[] =
 {
   /* In a series of synonyms, present the most meaningful first, so
      that argmatch_valid be more readable.  */
-  "none       - no warnings",
-  "error      - warnings are errors",
-  "yacc       - incompatibilities with POSIX YACC",
-  "all        - all of the above",
+  "none            - no warnings",
+  "midrule-values  - unset or unused midrule values",
+  "yacc            - incompatibilities with POSIX YACC",
+  "all             - all of the above",
+  "error           - warnings are errors",
   0
 };
 
 static const int warnings_types[] =
 {
   warnings_none,
-  warnings_error,
+  warnings_midrule_values,
   warnings_yacc,
-  warnings_all
+  warnings_all,
+  warnings_error
 };
 
 ARGMATCH_VERIFY (warnings_args, warnings_types);
@@ -233,52 +244,71 @@ usage (int status)
 	     program_name);
   else
     {
-      /* Some efforts were made to ease the translators' task, please
-	 continue.  */
+      printf (_("Usage: %s [OPTION]... FILE\n"), program_name);
       fputs (_("\
-GNU bison generates LALR(1) and GLR parsers.\n"), stdout);
-      putc ('\n', stdout);
-
-      fprintf (stdout, _("\
-Usage: %s [OPTION]... FILE\n"), program_name);
-      putc ('\n', stdout);
+Generate LALR(1) and GLR parsers.\n\
+\n\
+"), stdout);
 
       fputs (_("\
-If a long option shows an argument as mandatory, then it is mandatory\n\
-for the equivalent short option also.  Similarly for optional arguments.\n"),
-	     stdout);
-      putc ('\n', stdout);
+Mandatory arguments to long options are mandatory for short options too.\n\
+"), stdout);
+      fputs (_("\
+The same is true for optional arguments.\n\
+"), stdout);
 
       fputs (_("\
+\n\
 Operation modes:\n\
   -h, --help                 display this help and exit\n\
   -V, --version              output version information and exit\n\
       --print-localedir      output directory containing locale-dependent data\n\
-  -y, --yacc                 emulate POSIX Yacc\n"), stdout);
-      putc ('\n', stdout);
+      --print-datadir        output directory containing skeletons and XSLT\n\
+  -y, --yacc                 emulate POSIX Yacc\n\
+  -W, --warnings=[CATEGORY]  report the warnings falling in CATEGORY\n\
+\n\
+"), stdout);
 
       fputs (_("\
 Parser:\n\
+  -L, --language=LANGUAGE    specify the output programming language\n\
+                             (this is an experimental feature)\n\
   -S, --skeleton=FILE        specify the skeleton to use\n\
   -t, --debug                instrument the parser for debugging\n\
       --locations            enable locations computation\n\
   -p, --name-prefix=PREFIX   prepend PREFIX to the external symbols\n\
   -l, --no-lines             don't generate `#line' directives\n\
-  -n, --no-parser            generate the tables only\n\
   -k, --token-table          include a table of token names\n\
+\n\
 "), stdout);
-      putc ('\n', stdout);
 
+      /* Keep -d and --defines separate so that ../build-aux/cross-options.pl
+       * won't assume that -d also takes an argument.  */
       fputs (_("\
 Output:\n\
-  -d, --defines              also produce a header file\n\
+      --defines[=FILE]       also produce a header file\n\
+  -d                         likewise but cannot specify FILE (for POSIX Yacc)\n\
   -r, --report=THINGS        also produce details on the automaton\n\
+      --report-file=FILE     write report to FILE\n\
   -v, --verbose              same as `--report=state'\n\
   -b, --file-prefix=PREFIX   specify a PREFIX for output files\n\
   -o, --output=FILE          leave output to FILE\n\
-  -g, --graph                also produce a VCG description of the automaton\n\
+  -g, --graph[=FILE]         also output a graph of the automaton\n\
+  -x, --xml[=FILE]           also output an XML report of the automaton\n\
+                             (the XML schema is experimental)\n\
+\n\
+"), stdout);
+
+      fputs (_("\
+Warning categories include:\n\
+  `midrule-values'  unset or unused midrule values\n\
+  `yacc'            incompatibilities with POSIX YACC\n\
+  `all'             all the warnings\n\
+  `no-CATEGORY'     turn off warnings in CATEGORY\n\
+  `none'            turn off all the warnings\n\
+  `error'           treat warnings as errors\n\
+\n\
 "), stdout);
-      putc ('\n', stdout);
 
       fputs (_("\
 THINGS is a list of comma separated words that can include:\n\
@@ -289,10 +319,8 @@ THINGS is a list of comma separated words that can include:\n\
   `all'          include all the above information\n\
   `none'         disable the report\n\
 "), stdout);
-      putc ('\n', stdout);
 
-      fputs (_("\
-Report bugs to <" PACKAGE_BUGREPORT ">.\n"), stdout);
+      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
 
   exit (status);
@@ -310,12 +338,12 @@ version (void)
      continue.  */
   printf (_("bison (GNU Bison) %s"), VERSION);
   putc ('\n', stdout);
-  printf ("%s", revision);
   fputs (_("Written by Robert Corbett and Richard Stallman.\n"), stdout);
   putc ('\n', stdout);
 
   fprintf (stdout,
-	   _("Copyright (C) %d Free Software Foundation, Inc.\n"), 2006);
+	   _("Copyright (C) %d Free Software Foundation, Inc.\n"),
+	   PACKAGE_COPYRIGHT_YEAR);
 
   fputs (_("\
 This is free software; see the source for copying conditions.  There is NO\n\
@@ -325,18 +353,93 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 }
 
 
+/*-------------------------------------.
+| --skeleton and --language handling.  |
+`--------------------------------------*/
+
+void
+skeleton_arg (char const *arg, int prio, location const *loc)
+{
+  if (prio < skeleton_prio)
+    {
+      skeleton_prio = prio;
+      skeleton = arg;
+    }
+  else if (prio == skeleton_prio)
+    {
+      char const *msg =
+	_("multiple skeleton declarations are invalid");
+      if (loc)
+	complain_at (*loc, msg);
+      else
+	complain (msg);
+    }
+}
+
+void
+language_argmatch (char const *arg, int prio, location const *loc)
+{
+  char const *msg;
+
+  if (prio < language_prio)
+    {
+      int i;
+      for (i = 0; valid_languages[i].language[0]; i++)
+	if (c_strcasecmp (arg, valid_languages[i].language) == 0)
+	  {
+	    language_prio = prio;
+	    language = &valid_languages[i];
+	    return;
+	  }
+      msg = _("invalid language `%s'");
+    }
+  else if (language_prio == prio)
+    msg = _("multiple language declarations are invalid");
+  else
+    return;
+
+  if (loc)
+    complain_at (*loc, msg, arg);
+  else
+    complain (msg, arg);
+}
+
 /*----------------------.
 | Process the options.  |
 `----------------------*/
 
-/* Shorts options.  */
-static char const short_options[] = "yvegdhr:ltknVo:b:p:S:T::W";
+/* Shorts options.
+   Should be computed from long_options.  */
+static char const short_options[] =
+  "L:"
+  "S:"
+  "T::"
+  "V"
+  "W::"
+  "b:"
+  "d"
+  "e"
+  "g::"
+  "h"
+  "k"
+  "l"
+  "n"
+  "o:"
+  "p:"
+  "r:"
+  "t"
+  "v"
+  "x::"
+  "y"
+  ;
 
 /* Values for long options that do not have single-letter equivalents.  */
 enum
 {
   LOCATIONS_OPTION = CHAR_MAX + 1,
-  PRINT_LOCALEDIR_OPTION
+  PRINT_LOCALEDIR_OPTION,
+  PRINT_DATADIR_OPTION,
+  REPORT_FILE_OPTION
 };
 
 static struct option const long_options[] =
@@ -345,6 +448,7 @@ static struct option const long_options[] =
   { "help",            no_argument,	  0,   'h' },
   { "version",         no_argument,	  0,   'V' },
   { "print-localedir", no_argument,	  0,   PRINT_LOCALEDIR_OPTION },
+  { "print-datadir",   no_argument,	  0,   PRINT_DATADIR_OPTION   },
   { "warnings",        optional_argument, 0,   'W' },
 
   /* Parser. */
@@ -356,7 +460,9 @@ static struct option const long_options[] =
   { "output",	   required_argument,	0,   'o' },
   { "output-file", required_argument,	0,   'o' },
   { "graph",	   optional_argument,	0,   'g' },
+  { "xml",         optional_argument,   0,   'x' },
   { "report",	   required_argument,   0,   'r' },
+  { "report-file", required_argument,   0,   REPORT_FILE_OPTION },
   { "verbose",	   no_argument,	        0,   'v' },
 
   /* Hidden. */
@@ -373,9 +479,9 @@ static struct option const long_options[] =
   { "debug",	      no_argument,               0,   't' },
   { "locations",      no_argument,		 0, LOCATIONS_OPTION },
   { "no-lines",       no_argument,               0,   'l' },
-  { "no-parser",      no_argument,               0,   'n' },
   { "raw",            no_argument,               0,     0 },
   { "skeleton",       required_argument,         0,   'S' },
+  { "language",       required_argument,         0,   'L' },
   { "token-table",    no_argument,               0,   'k' },
 
   {0, 0, 0, 0}
@@ -402,35 +508,53 @@ getargs (int argc, char *argv[])
 	/* Certain long options cause getopt_long to return 0.  */
 	break;
 
-      case 'b':
-	spec_file_prefix = AS_FILE_NAME (optarg);
-	break;
-
-      case 'g':
-	/* Here, the -g and --graph=FILE options are differentiated.  */
-	graph_flag = true;
+      case 'd':
+	/* Here, the -d and --defines options are differentiated.  */
+	defines_flag = true;
 	if (optarg)
-	  spec_graph_file = AS_FILE_NAME (optarg);
-	break;
-
-      case 'h':
-	usage (EXIT_SUCCESS);
-
-      case 'S':
-	skeleton = AS_FILE_NAME (optarg);
+	  spec_defines_file = xstrdup (AS_FILE_NAME (optarg));
 	break;
 
       case 'I':
 	include = AS_FILE_NAME (optarg);
 	break;
 
-      case 'd':
-	/* Here, the -d and --defines options are differentiated.  */
-	defines_flag = true;
-	if (optarg)
-	  spec_defines_file = AS_FILE_NAME (optarg);
+      case 'L':
+	language_argmatch (optarg, command_line_prio, NULL);
 	break;
 
+      case 'S':
+	skeleton_arg (AS_FILE_NAME (optarg), command_line_prio, NULL);
+	break;
+
+      case 'T':
+	FLAGS_ARGMATCH (trace, optarg);
+	break;
+
+      case 'V':
+	version ();
+	exit (EXIT_SUCCESS);
+
+      case 'W':
+	if (optarg)
+	  FLAGS_ARGMATCH (warnings, optarg);
+	else
+	  warnings_flag |= warnings_all;
+	break;
+
+      case 'b':
+	spec_file_prefix = AS_FILE_NAME (optarg);
+	break;
+
+      case 'g':
+	graph_flag = true;
+	if (optarg)
+	  spec_graph_file = xstrdup (AS_FILE_NAME (optarg));
+	break;
+
+      case 'h':
+	usage (EXIT_SUCCESS);
+
       case 'k':
 	token_table_flag = true;
 	break;
@@ -439,10 +563,6 @@ getargs (int argc, char *argv[])
 	no_lines_flag = true;
 	break;
 
-      case 'n':
-	no_parser_flag = true;
-	break;
-
       case 'o':
 	spec_outfile = AS_FILE_NAME (optarg);
 	break;
@@ -455,28 +575,22 @@ getargs (int argc, char *argv[])
 	FLAGS_ARGMATCH (report, optarg);
 	break;
 
-      case 'T':
-	FLAGS_ARGMATCH (trace, optarg);
-	break;
-
       case 't':
 	debug_flag = true;
 	break;
 
-      case 'V':
-	version ();
-	exit (EXIT_SUCCESS);
-
       case 'v':
 	report_flag |= report_states;
 	break;
 
-      case 'y':
-	yacc_flag = true;
+      case 'x':
+	xml_flag = true;
+	if (optarg)
+	  spec_xml_file = xstrdup (AS_FILE_NAME (optarg));
 	break;
 
-      case 'W':
-	FLAGS_ARGMATCH (warnings, optarg);
+      case 'y':
+	yacc_flag = true;
 	break;
 
       case LOCATIONS_OPTION:
@@ -487,6 +601,14 @@ getargs (int argc, char *argv[])
 	printf ("%s\n", LOCALEDIR);
 	exit (EXIT_SUCCESS);
 
+      case PRINT_DATADIR_OPTION:
+	printf ("%s\n", compute_pkgdatadir ());
+	exit (EXIT_SUCCESS);
+
+      case REPORT_FILE_OPTION:
+	spec_verbose_file = xstrdup (AS_FILE_NAME (optarg));
+	break;
+
       default:
 	usage (EXIT_FAILURE);
       }
