@@ -1,24 +1,22 @@
 /* Definitions for symtab.c and callers, part of Bison.
 
-   Copyright (C) 1984, 1989, 1992, 2000, 2001, 2002, 2004, 2005, 2006
+   Copyright (C) 1984, 1989, 1992, 2000, 2001, 2002, 2004, 2005, 2006, 2007
    Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
-   Bison is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-   Bison is distributed in the hope that it will be useful,
+   This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Bison; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /**
  * \file symtab.h
@@ -30,6 +28,7 @@
 
 # include "assoc.h"
 # include "location.h"
+# include "scan-code.h"
 # include "uniqstr.h"
 
 /*----------.
@@ -69,28 +68,16 @@ struct symbol
   /** Any \c \%destructor declared specifically for this symbol.
 
      Access this field only through <tt>symbol</tt>'s interface functions.  For
-     example, if <tt>symbol::destructor = NULL</tt>, the default
-     \c \%destructor or a per-type \c \%destructor might be appropriate, and
+     example, if <tt>symbol::destructor = NULL</tt>, a default \c \%destructor
+     or a per-type \c \%destructor might be appropriate, and
      \c symbol_destructor_get will compute the correct one.  */
-  const char *destructor;
-
-  /** The location of \c symbol::destructor.
-
-     Access this field only through <tt>symbol</tt>'s interface functions.
-     \sa symbol::destructor  */
-  location destructor_location;
+  code_props destructor;
 
   /** Any \c \%printer declared specifically for this symbol.
 
      Access this field only through <tt>symbol</tt>'s interface functions.
      \sa symbol::destructor  */
-  const char *printer;
-
-  /** The location of \c symbol::printer.
-
-     Access this field only through <tt>symbol</tt>'s interface functions.
-     \sa symbol::destructor  */
-  location printer_location;
+  code_props printer;
 
   symbol_number number;
   location prec_location;
@@ -143,27 +130,22 @@ void symbol_make_alias (symbol *sym, symbol *symval, location loc);
     Do nothing if passed 0 as \c type_name.  */
 void symbol_type_set (symbol *sym, uniqstr type_name, location loc);
 
+/** Get the \c class string associated with \c sym.  */
+const char *symbol_class_get_string (symbol *sym);
+
 /** Set the \c destructor associated with \c sym.  */
-void symbol_destructor_set (symbol *sym, const char *destructor, location loc);
+void symbol_destructor_set (symbol *sym, code_props const *destructor);
 
-/** Get the computed \c \%destructor for \c sym, or \c NULL if none.   */
-const char *symbol_destructor_get (symbol *sym);
-
-/** Get the grammar location of the computed \c \%destructor for \c sym.
- 
-  \pre <tt>symbol_destructor_get (sym) != NULL</tt> */
-location symbol_destructor_location_get (symbol *sym);
+/** Get the computed \c \%destructor for \c sym, which was initialized with
+    \c code_props_none_init if there's no \c \%destructor.  */
+code_props const *symbol_destructor_get (symbol const *sym);
 
 /** Set the \c printer associated with \c sym.  */
-void symbol_printer_set (symbol *sym, const char *printer, location loc);
+void symbol_printer_set (symbol *sym, code_props const *printer);
 
-/** Get the computed \c \%printer for \c sym, or \c NULL if none.  */
-const char *symbol_printer_get (symbol *sym);
-
-/** Get the grammar location of the computed \c \%printer for \c sym.
-
-  \pre <tt>symbol_printer_get (sym) != NULL</tt> */
-location symbol_printer_location_get (symbol *sym);
+/** Get the computed \c \%printer for \c sym, which was initialized with
+    \c code_props_none_init if there's no \c \%printer.  */
+code_props const *symbol_printer_get (symbol const *sym);
 
 /* Set the \c precedence associated with \c sym.
 
@@ -201,22 +183,17 @@ extern location startsymbol_location;
 `-----------------*/
 
 /** A semantic type and its associated \c \%destructor and \c \%printer.
-   
+
    Access the fields of this struct only through the interface functions in
    this file.  \sa symbol::destructor  */
-typedef struct semantic_type {
+typedef struct {
   /** The key, name of the semantic type.  */
   uniqstr tag;
 
   /** Any \c %destructor declared for this semantic type.  */
-  const char *destructor;
-  /** The location of \c semantic_type::destructor.  */
-  location destructor_location;
-
+  code_props destructor;
   /** Any \c %printer declared for this semantic type.  */
-  const char *printer;
-  /** The location of \c semantic_type::printer.  */
-  location printer_location;
+  code_props printer;
 } semantic_type;
 
 /** Fetch (or create) the semantic type associated to KEY.  */
@@ -226,12 +203,12 @@ semantic_type *semantic_type_from_uniqstr (const uniqstr key);
 semantic_type *semantic_type_get (const char *key);
 
 /** Set the \c destructor associated with \c type.  */
-void semantic_type_destructor_set (semantic_type *type, const char *destructor,
-                                   location loc);
+void semantic_type_destructor_set (semantic_type *type,
+                                   code_props const *destructor);
 
 /** Set the \c printer associated with \c type.  */
-void semantic_type_printer_set (semantic_type *type, const char *printer,
-                                location loc);
+void semantic_type_printer_set (semantic_type *type,
+                                code_props const *printer);
 
 /*----------------------------------.
 | Symbol and semantic type tables.  |
@@ -255,14 +232,18 @@ void symbols_check_defined (void);
 void symbols_pack (void);
 
 
-/*-----------------------------------.
-| Default %destructor and %printer.  |
-`-----------------------------------*/
+/*---------------------------------------.
+| Default %destructor's and %printer's.  |
+`---------------------------------------*/
 
-/** Set the default \c \%destructor.  */
-void default_destructor_set (const char *destructor, location loc);
+/** Set the default \c \%destructor for tagged values.  */
+void default_tagged_destructor_set (code_props const *destructor);
+/** Set the default \c \%destructor for tagless values.  */
+void default_tagless_destructor_set (code_props const *destructor);
 
-/** Set the default \c \%printer.  */
-void default_printer_set (const char *printer, location loc);
+/** Set the default \c \%printer for tagged values.  */
+void default_tagged_printer_set (code_props const *printer);
+/** Set the default \c \%printer for tagless values.  */
+void default_tagless_printer_set (code_props const *printer);
 
 #endif /* !SYMTAB_H_ */
